==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_arrows.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_arrows.gif"

unsigned char _mgir_gif_skin_arrows_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x07,0x00,	0x70,0x00,0x91,0x00,0x00,0xFF,0xFF,0xFF,
	0xDE,0xDE,0xDE,0xFF,0xFF,0xFF,0x00,0x00,	0x00,0x21,0xF9,0x04,0x01,0x00,0x00,0x02,
	0x00,0x2C,0x00,0x00,0x00,0x00,0x07,0x00,	0x70,0x00,0x00,0x02,0x7B,0x94,0x8F,0x69,
	0x90,0xE0,0xE7,0xA2,0x90,0x52,0xD9,0xBB,	0xDA,0x5B,0x91,0xD1,0x8D,0x85,0x90,0xC6,
	0x70,0x9F,0x07,0x8A,0x61,0x90,0x04,0xEE,	0xE1,0xC6,0x82,0x2C,0xAB,0xD7,0x39,0x75,
	0x50,0x3A,0xD9,0x22,0xDE,0x29,0xE5,0x84,	0x19,0x1F,0x06,0xA8,0x33,0x35,0x8C,0x18,
	0xDA,0x2B,0xF6,0x32,0xD4,0x60,0x3E,0x62,	0x0E,0x51,0x19,0x92,0x34,0x0A,0x6B,0x0F,
	0x4B,0xCC,0x66,0x95,0xE0,0xAE,0xB9,0xBC,	0x13,0x8E,0xB5,0x68,0xAC,0x82,0x85,0x88,
	0x4A,0xE5,0xD3,0x39,0x1C,0x76,0xA7,0x8E,	0xB8,0x60,0xAB,0x38,0xC5,0xE3,0x25,0xE8,
	0x17,0x08,0x32,0x16,0x78,0xD6,0x46,0x96,	0xC6,0xB8,0xB3,0xD4,0xF2,0x96,0x37,0x23,
	0x67,0x87,0x97,0x47,0x39,0x83,0x50,0x00,	0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_arrows.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_arrows.gif"

const unsigned char _mgir_gif_skin_arrows_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x07,0x00,	0x70,0x00,0x91,0x00,0x00,0xFF,0xFF,0xFF,
	0xDE,0xDE,0xDE,0xFF,0xFF,0xFF,0x00,0x00,	0x00,0x21,0xF9,0x04,0x01,0x00,0x00,0x02,
	0x00,0x2C,0x00,0x00,0x00,0x00,0x07,0x00,	0x70,0x00,0x00,0x02,0x7B,0x94,0x8F,0x69,
	0x90,0xE0,0xE7,0xA2,0x90,0x52,0xD9,0xBB,	0xDA,0x5B,0x91,0xD1,0x8D,0x85,0x90,0xC6,
	0x70,0x9F,0x07,0x8A,0x61,0x90,0x04,0xEE,	0xE1,0xC6,0x82,0x2C,0xAB,0xD7,0x39,0x75,
	0x50,0x3A,0xD9,0x22,0xDE,0x29,0xE5,0x84,	0x19,0x1F,0x06,0xA8,0x33,0x35,0x8C,0x18,
	0xDA,0x2B,0xF6,0x32,0xD4,0x60,0x3E,0x62,	0x0E,0x51,0x19,0x92,0x34,0x0A,0x6B,0x0F,
	0x4B,0xCC,0x66,0x95,0xE0,0xAE,0xB9,0xBC,	0x13,0x8E,0xB5,0x68,0xAC,0x82,0x85,0x88,
	0x4A,0xE5,0xD3,0x39,0x1C,0x76,0xA7,0x8E,	0xB8,0x60,0xAB,0x38,0xC5,0xE3,0x25,0xE8,
	0x17,0x08,0x32,0x16,0x78,0xD6,0x46,0x96,	0xC6,0xB8,0xB3,0xD4,0xF2,0x96,0x37,0x23,
	0x67,0x87,0x97,0x47,0x39,0x83,0x50,0x00,	0x00,0x3B
};
#endif //_MGINCORE_RES
